Event

Struct Event 

pub struct Event {
    pub time_unix_nano: u64,
    pub name: String,
    pub attributes: Vec<KeyValue>,
    pub dropped_attributes_count: u32,
}
Event is a time-stamped annotation of the span, consisting of user-supplied text description and key-value pairs.

Fields

time_unix_nano: u64

time_unix_nano is the time the event occurred.

name: String

name of the event. This field is semantically required to be set to non-empty string.

attributes: Vec<KeyValue>

attributes is a collection of attribute key/value pairs on the event. Attribute keys MUST be unique (it is not allowed to have more than one attribute with the same key).

The attribute values SHOULD NOT contain empty values. The attribute values SHOULD NOT contain bytes values. The attribute values SHOULD NOT contain array values different than array of string values, bool values, int values, double values. The attribute values SHOULD NOT contain kvlist values. The behavior of software that receives attributes containing such values can be unpredictable. These restrictions can change in a minor release. The restrictions take origin from the OpenTelemetry specification: https://github.com/open-telemetry/opentelemetry-specification/blob/v1.47.0/specification/common/README.md#attribute.

dropped_attributes_count: u32

dropped_attributes_count is the number of dropped attributes. If the value is 0, then no attributes were dropped.